Examples
========
Here are the Examples.

.. toctree::
   :maxdepth: 2
   :caption: Examples:
    
   example_notebooks/mixed_logit_correlated_example
   example_notebooks/mixed_logit_model_xlogit_example
   example_notebooks/batching_example
   example_notebooks/scikit_cross_validation
   example_notebooks/mixed_logit_comparison_example
